/* ******************************************************************

   author     : puehringer edgar

   compiler   : javac             

   class      : DateChooserPanel
   date       : 28.11.97
   description: a panel that allows you to choose a date
   modified   : 9.2.98 - new constructors for locale scheme added

*********************************************************************/

/* ******************************************************************
   import statements
*********************************************************************/

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.text.SimpleDateFormat;

/* ******************************************************************
   top level class declaration
*********************************************************************/

public class DateChooserPanel extends Panel
  implements ActionListener, ItemListener, ItemSelectable {

  // instance variable declarations
  private Calendar calendar;
  private Vector listenerVector;
  private SimpleDateFormat formatter;
  private DateChooserCanvas dayChooser;
  private boolean isMouseSelected;
  private Label label;
  private Button up;
  private Button down;

  // constructors
  public DateChooserPanel() {
    this.calendar = new GregorianCalendar();
    dayChooser    = new DateChooserCanvas(this.calendar);
    init();
  } // end constructor DateChooserPanel

  public DateChooserPanel(Calendar calendar) {
    this.calendar = (Calendar)calendar.clone();
    dayChooser    = new DateChooserCanvas(this.calendar);
    init();
  } // end constructor DateChooserPanel

  public DateChooserPanel(Calendar calendar, Calendar today) {
    this.calendar = (Calendar)calendar.clone();
    dayChooser    = new DateChooserCanvas(this.calendar,today);
    init();
  } // end constructor DateChooserPanel

  public DateChooserPanel(Calendar calendar, Locale locale) {
    this.calendar = (Calendar)calendar.clone();
    dayChooser    = new DateChooserCanvas(this.calendar,locale);
    init();
  } // end constructor DateChooserPanel

  public DateChooserPanel(Calendar calendar, Calendar today, Locale locale) {
    this.calendar = (Calendar)calendar.clone();
    dayChooser    = new DateChooserCanvas(this.calendar,today,locale);
    init();
  } // end constructor DateChooserPanel

  // methods
  private void init() {
    formatter       = new SimpleDateFormat("MMMM yyyy");
    listenerVector  = new Vector();
    isMouseSelected = false;
    GridBagLayout gridbag = new GridBagLayout();
    GridBagConstraints constraints = new GridBagConstraints();
    setLayout(gridbag);
    Panel panel = new Panel();
    down        = new Button("<");
    down.addActionListener(this);
    panel.add(down);

    up = new Button(">");
    up.addActionListener(this);
    panel.add(up);

    label = new Label("");
    updateAndNotify();
    panel.add(label);

    dayChooser.addItemListener(this);

    constraints.weightx    = 1.0;
    constraints.weighty    = 1.0; 
    constraints.gridwidth  = GridBagConstraints.REMAINDER; 
    constraints.gridheight = GridBagConstraints.RELATIVE;
    gridbag.setConstraints(dayChooser,constraints); 
    add(dayChooser);

    constraints.gridheight = GridBagConstraints.REMAINDER;
    gridbag.setConstraints(panel,constraints); 
    add(panel);

  } // end init

  private void updateAndNotify() {
    ItemEvent e  = new ItemEvent(this,ItemEvent.ITEM_STATE_CHANGED,
                     calendar,ItemEvent.SELECTED);
    String str = formatter.format(calendar.getTime());
    int n      = str.length();
    int i;

    for (i=n; i<14; i++) str += "  ";  // to prevent long month names from cut
                                       // of by label
    label.setText(str);
    for (i=0; i<listenerVector.size(); i++) {
      ((ItemListener)listenerVector.elementAt(i)).itemStateChanged(e);
    } // end for
  } // end updateAndNotify


  public void actionPerformed(ActionEvent e) {
    String cmd = e.getActionCommand();

    if (cmd.equals("<")) {
      calendar.add(Calendar.MONTH,-1);
    }
    else {
      calendar.add(Calendar.MONTH,1);
    } // end if
    dayChooser.setDate(calendar.getTime());
    isMouseSelected = false;
    updateAndNotify();
  } // end actionPerformed

  public void itemStateChanged(ItemEvent e) {
    calendar.setTime(dayChooser.getDate());
    isMouseSelected = true;
    updateAndNotify();
  } // end itemStateChanged

  public Date getDate() {
    return calendar.getTime();
  } // end getDate

  public void setDate(Date date) {
    calendar.setTime(date);
    dayChooser.setDate(calendar.getTime());
    updateAndNotify();
  } // end getDate

  public boolean getMouseSelected() {
    return isMouseSelected;
  } // end getMouseSelected

  public synchronized void addItemListener(ItemListener l) {
    listenerVector.addElement(l);
  } // end addItemListener

  public synchronized void removeItemListener(ItemListener l) {
    listenerVector.removeElement(l);
  } // end addItemListener

  public Object[] getSelectedObjects() {
    return null;
  } // end getSelectedObject

} // end DateChooserPanel

/* ******************************************************************
   end of file
*********************************************************************/
