/* ******************************************************************

   author     : puehringer edgar

   compiler   : javac (jdk 1.1.3)

   class      : DocVer
   date       : 2.10.97
   description: a class that represents version information for
                documents

*********************************************************************/

/* ******************************************************************
   import statements
*********************************************************************/

import java.io.*;

/* ******************************************************************
   top level class declaration
*********************************************************************/

public class DocVer implements Streamable, Cloneable {

  // instance variable declarations
  String documentType;                 // name of app that created the doc
  String documentVersion;              // os version of document
  String documentRelease;              // release number as string
  private boolean lastInSeq;           // true if element is last in a sequence

  // constructors
  public DocVer(String docType, String docRelease) {
    documentType    = docType;
    documentVersion = System.getProperty("os.name");
    documentRelease = docRelease;
    lastInSeq       = false;
  } // end constructor DocVer

  public DocVer(DataInput in) throws IOException {
    inputFrom(in);
  } // end constructor DocVer

  // methods
  public String toString() {
    return documentType+"\n"+documentVersion+"\n"+documentRelease+"\n";
  } // end toString

  public boolean equals(DocVer docVer) {
    return documentType.equals(docVer.documentType) &&
           documentRelease.equals(docVer.documentRelease);
  } // end equals

  public String getHeadline() {
    return documentType+" Version "+documentRelease;
  } // end getHeadline;

  public void outputTo(DataOutput out) throws IOException {

   out.writeUTF(documentType);
   out.writeUTF(documentVersion);
   out.writeUTF(documentRelease);
   out.writeBoolean(lastInSeq);
  } // end outputTo

  public void inputFrom(DataInput in) throws IOException {
    
    documentType    = in.readUTF();
    documentVersion = in.readUTF();
    documentRelease = in.readUTF();
    lastInSeq       = in.readBoolean();
  } // end inputFrom

  public void setLastInSeq(boolean lastInSeq) {
  // sets if object is the last in a sequence or not

    this.lastInSeq = lastInSeq;
  } // end setLastInSeq

  public boolean isLastInSeq() {
  // indicates if object is the last in a sequence or not

    return lastInSeq;
  } // end isLastInSeq

  // public void deleteOn(DataOutput out) throws IOException {
     // do nothing - DocVer objects can't be marked as deleted
  //} // end deleteOn

  //public boolean isDeleted() {
  //
  //  return false;

  //} // end isDeleted

  public Object clone() {

    return new DocVer(documentType,documentRelease);
  } // end clone

} // end DocVer

/* ******************************************************************
   end of file
*********************************************************************/
