/* ******************************************************************

   author     : puehringer edgar

   compiler   : javac (jdk 1.1.5)

   class      : FilePool
   date       : 15.10.97
   description: a class to get calendar file from a shared pool

*********************************************************************/

/* ******************************************************************
   import statements
*********************************************************************/

import java.io.*;
import java.util.*;

/* ******************************************************************
   top level class declaration
*********************************************************************/

public class FilePool {

  // instance variable declarations
  private DocVer docVer;
  private File workDir;
  private Hashtable hash;

  // constructors
  public FilePool(DocVer versionInfo, File workDir) {
    docVer         = versionInfo;
    this.workDir   = workDir;
    hash           = new Hashtable();
  } // end constructor FilePool

  // methods
  public synchronized CalendarFile get(String fileName) {
    CalendarFile cFile;

    if ((!hash.isEmpty()) && hash.containsKey(fileName))
      cFile = (CalendarFile)hash.get(fileName);
    else {
      cFile = new CalendarFile(docVer,new File(workDir,fileName));
      hash.put(fileName,cFile);
    } // end if
    cFile.incRefCounter();
    return cFile;
  } // end get

  public synchronized void release(String fileName) throws IOException {
    CalendarFile cFile;

    //if (hash.isEmpty() || (!hash.contains(fileName))) {
    if (hash.isEmpty() || (!hash.containsKey(fileName))) return;
    cFile = (CalendarFile)hash.get(fileName);
    cFile.decRefCounter();
    if (!cFile.isRefered()) hash.remove(fileName);
  } // end release

  public synchronized int getNrOfFiles() {
    return hash.size();
  } // end getNrOfFiles

} // end FilePool;

/* ******************************************************************
   end of file
*********************************************************************/
