/* ******************************************************************

   author     : puehringer edgar

   compiler   : javac (jdk 1.1.5)

   class      : GetMsgDlg
   date       : 13.2.98
   description: a dialog that displays dates added or modified by
                other users
   modified   : 13.03.98 - dialog is no longer initially visible

*********************************************************************/

/* ******************************************************************
   import statements
*********************************************************************/


import java.awt.*; 
import java.awt.event.*;
import java.util.*;
import java.text.SimpleDateFormat;

/* ******************************************************************
   top level class declaration
*********************************************************************/

public class GetMsgDlg extends Dialog implements ActionListener {

  // instance variable declarations
  private Frame parent;
  private boolean canceled    = false;
  private boolean autoCancel  = false;
  private boolean autoDisable = false;
  private Button okButton;
  private Button viewButton;
  private List list;
  private Vector changedDates;

  // inner classes
  class GetMsgDlgListener extends WindowAdapter {

    // methods
    public void windowClosing(WindowEvent e) {
      setCanceled(true);
      setVisible(false);
      dispose();
    } // end windowClosing

    public void windowActivated(WindowEvent e) {
    } // end WindowActivated

    public void windowDeactivated(WindowEvent e) {
      if (autoCancel) {
        setCanceled(true);
        setVisible(false);
        dispose();
      } // end if
    } // end WindowDeactivated

  } // end GetMsgDlgListener

  class EditDlgListener extends WindowAdapter {

    public void windowClosed(WindowEvent e) {
      autoCancel  = true;
      autoDisable = false;
    } // end windowClosed
  
  } // end EditDlgListener

  // costructors
  public GetMsgDlg(Frame parent, Vector changedDates) {
    super(parent);
    this.parent       = parent;
    this.changedDates = changedDates;
    init();
  } // end constructor GetMsgDlg

  public GetMsgDlg(Frame parent, boolean modal, Vector changedDates) {
    super(parent,modal);
    this.parent       = parent;
    this.changedDates = changedDates;
    init();
  } // end constructor GetMsgDlg

  public GetMsgDlg(Frame parent, String title, Vector changedDates) {
    super(parent,title);
    this.parent       = parent;
    this.changedDates = changedDates;
    init();
  } // end constructor GetMsgDlg

  public GetMsgDlg(Frame parent, String title,
                         boolean modal, Vector changedDates) {
    super(parent,title,modal);
    this.parent       = parent;
    this.changedDates = changedDates;
    init();
  } // end constructor GetMsgDlg

  // methods
  private void init() {
    addWindowListener(new GetMsgDlgListener());
    // this dialog box uses the gridbaglayout to provide a pretty good layout
    GridBagLayout gridbag          = new GridBagLayout(); 
    GridBagConstraints constraints = new GridBagConstraints();

    // create the widgets
    InsetsPanel pan = new InsetsPanel(new Insets(15,20,15,20));
    okButton = new Button("OK");
    okButton.addActionListener(this);
    viewButton = new Button("View");
    viewButton.addActionListener(this);
    InsetsPanel buttonPanel = new InsetsPanel(new Insets(15,0,0,0));
    buttonPanel.setLayout(new GridLayout(1,2,10,0));
    buttonPanel.add(okButton);
    buttonPanel.add(viewButton);

    // set up the list
    {
      int n = changedDates.size();
      int i;
      String str;
      CalendarEntry entry;
      SimpleDateFormat formatter = new SimpleDateFormat("d.MM.yy H:mm, ",
                                         CalendarCreator.getLocale());
      list = new List(5,false);
      for (i=0; i<n; i++) {
        entry = (CalendarEntry)changedDates.elementAt(i);
        if (entry.isDeletedInstance() || entry.isDeleted())
          str = "Deleted: ";
        else if (entry.getOldVersion() != null)
          str = "Modified: ";
        else
          str = "Added: ";
        // end if
        str += formatter.format(entry.getStart());
        str += entry.getCreator() + ": ";
        str += entry.getDescription();
        list.add(str);
      } // end for
      list.select(0);
    }

    Label label = getDescriptionLabel();

    pan.setLayout(gridbag); 

    constraints.fill       = GridBagConstraints.NONE; 
    constraints.anchor     = GridBagConstraints.WEST; 
    constraints.weightx    = 1.0; 
    constraints.weighty    = 1.0; 
    constraints.gridwidth  = GridBagConstraints.REMAINDER; 
    constraints.gridheight = 1; 
    gridbag.setConstraints(label,constraints); 
    pan.add(label); 

    constraints.anchor     = GridBagConstraints.CENTER; 
    constraints.gridheight = GridBagConstraints.RELATIVE; 
    gridbag.setConstraints(list,constraints); 
    pan.add(list); 

    constraints.gridheight = GridBagConstraints.REMAINDER; 
    gridbag.setConstraints(buttonPanel, constraints); 
    pan.add(buttonPanel); 

    add(pan);
    pack(); 
    setResizable(false);
    //setVisible(true);
  } // end init

  protected Label getDescriptionLabel() {
    return new Label("The following dates were added or modified"+
                     " from other users:");
  } // end getDescriptionLabel

  public void actionPerformed(ActionEvent e) {
    String cmd = e.getActionCommand();

    if (cmd.equals("View")) {
      int index           = list.getSelectedIndex();
      CalendarEntry entry = (CalendarEntry)changedDates.elementAt(index);
      EditDateDlg editDlg = new EditDateDlg(parent,"View Date",isModal(),
                                            entry,EditDateDlg.VIEW,
                                            entry.getPersons());
      if (autoCancel) {
        autoCancel = false;
        autoDisable = true;
        editDlg.addWindowListener(new EditDlgListener());
        editDlg.setAutoCancel(true);
      } // end if
      editDlg.setVisible(true);
    }
    else { // if cmd equals Ok
      setVisible(false);
      dispose();
    } // end if
  } // end actionPerformed

  public boolean getCanceled() {
    return canceled;
  } // end getCanceled

  public void setCanceled(boolean canceled) {
    this.canceled = canceled;
  } // end getCanceled

  public boolean getAutoCancel() {
    return autoCancel;
  } // end getAutoCancel

  public void setAutoCancel(boolean autoCancel) {
    this.autoCancel = autoCancel;
  } // end getAutoCancel

} // end GetMsgDlg

/* ******************************************************************
   end of file
*********************************************************************/
